==> citrus-spring-4.0.2-sources.jar: org/citrusframework/model/config/core/BeforeSuiteModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.3 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.core;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAnyElement;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="env" type="{http://www.citrusframework.org/schema/config}PropertiesType" minOccurs="0"/>
 *         <element name="system" type="{http://www.citrusframework.org/schema/config}PropertiesType" minOccurs="0"/>
 *         <element name="actions">
 *           <complexType>
 *             <complexContent>
 *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 <sequence>
 *                   <choice maxOccurs="unbounded">
 *                     <any namespace='http://www.citrusframework.org/schema/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/jms/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/ws/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/http/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/camel/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/selenium/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/docker/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/kubernetes/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/zookeeper/testcase'/>
 *                   </choice>
 *                 </sequence>
 *               </restriction>
 *             </complexContent>
 *           </complexType>
 *         </element>
 *       </sequence>
 *       <attribute name="id" use="required" type="{http://www.w3.org/2001/XMLSchema}ID" />
 *       <attribute name="suites" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="groups" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "env",
    "system",
    "actions"
})
@XmlRootElement(name = "before-suite")
public class BeforeSuiteModel {

    protected PropertiesType env;
    protected PropertiesType system;
    @XmlElement(required = true)
    protected BeforeSuiteModel.Actions actions;
    @XmlAttribute(name = "id", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "suites")
    protected String suites;
    @XmlAttribute(name = "groups")
    protected String groups;

    /**
     * Ruft den Wert der env-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link PropertiesType }
     *     
     */
    public PropertiesType getEnv() {
        return env;
    }

    /**
     * Legt den Wert der env-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link PropertiesType }
     *     
     */
    public void setEnv(PropertiesType value) {
        this.env = value;
    }

    /**
     * Ruft den Wert der system-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link PropertiesType }
     *     
     */
    public PropertiesType getSystem() {
        return system;
    }

    /**
     * Legt den Wert der system-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link PropertiesType }
     *     
     */
    public void setSystem(PropertiesType value) {
        this.system = value;
    }

    /**
     * Ruft den Wert der actions-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link BeforeSuiteModel.Actions }
     *     
     */
    public BeforeSuiteModel.Actions getActions() {
        return actions;
    }

    /**
     * Legt den Wert der actions-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link BeforeSuiteModel.Actions }
     *     
     */
    public void setActions(BeforeSuiteModel.Actions value) {
        this.actions = value;
    }

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Ruft den Wert der suites-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSuites() {
        return suites;
    }

    /**
     * Legt den Wert der suites-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSuites(String value) {
        this.suites = value;
    }

    /**
     * Ruft den Wert der groups-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGroups() {
        return groups;
    }

    /**
     * Legt den Wert der groups-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGroups(String value) {
        this.groups = value;
    }


    /**
     * <p>Java-Klasse für anonymous complex type.
     * 
     * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <sequence>
     *         <choice maxOccurs="unbounded">
     *           <any namespace='http://www.citrusframework.org/schema/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/jms/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/ws/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/http/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/camel/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/selenium/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/docker/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/kubernetes/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/zookeeper/testcase'/>
     *         </choice>
     *       </sequence>
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "anies"
    })
    public static class Actions {

        @XmlAnyElement(lax = true)
        protected List<Object> anies;

        /**
         * Gets the value of the anies property.
         * 
         * <p>
         * This accessor method returns a reference to the live list,
         * not a snapshot. Therefore any modification you make to the
         * returned list will be present inside the Jakarta XML Binding object.
         * This is why there is not a {@code set} method for the anies property.
         * 
         * <p>
         * For example, to add a new item, do as follows:
         * <pre>
         *    getAnies().add(newItem);
         * </pre>
         * 
         * 
         * <p>
         * Objects of the following type(s) are allowed in the list
         * {@link Object }
         * 
         * 
         * @return
         *     The value of the anies property.
         */
        public List<Object> getAnies() {
            if (anies == null) {
                anies = new ArrayList<>();
            }
            return this.anies;
        }

    }

}

==> citrus-spring-4.1.1-sources.jar: org/citrusframework/model/config/core/BeforeSuiteModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.4 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.core;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAnyElement;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.</p>
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="env" type="{http://www.citrusframework.org/schema/config}PropertiesType" minOccurs="0"/>
 *         <element name="system" type="{http://www.citrusframework.org/schema/config}PropertiesType" minOccurs="0"/>
 *         <element name="actions">
 *           <complexType>
 *             <complexContent>
 *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 <sequence>
 *                   <choice maxOccurs="unbounded">
 *                     <any namespace='http://www.citrusframework.org/schema/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/jms/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/ws/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/http/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/camel/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/selenium/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/docker/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/kubernetes/testcase'/>
 *                     <any namespace='http://www.citrusframework.org/schema/zookeeper/testcase'/>
 *                   </choice>
 *                 </sequence>
 *               </restriction>
 *             </complexContent>
 *           </complexType>
 *         </element>
 *       </sequence>
 *       <attribute name="id" use="required" type="{http://www.w3.org/2001/XMLSchema}ID" />
 *       <attribute name="suites" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="groups" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "env",
    "system",
    "actions"
})
@XmlRootElement(name = "before-suite")
public class BeforeSuiteModel {

    protected PropertiesType env;
    protected PropertiesType system;
    @XmlElement(required = true)
    protected BeforeSuiteModel.Actions actions;
    @XmlAttribute(name = "id", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "suites")
    protected String suites;
    @XmlAttribute(name = "groups")
    protected String groups;

    /**
     * Ruft den Wert der env-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link PropertiesType }
     *     
     */
    public PropertiesType getEnv() {
        return env;
    }

    /**
     * Legt den Wert der env-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link PropertiesType }
     *     
     */
    public void setEnv(PropertiesType value) {
        this.env = value;
    }

    /**
     * Ruft den Wert der system-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link PropertiesType }
     *     
     */
    public PropertiesType getSystem() {
        return system;
    }

    /**
     * Legt den Wert der system-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link PropertiesType }
     *     
     */
    public void setSystem(PropertiesType value) {
        this.system = value;
    }

    /**
     * Ruft den Wert der actions-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link BeforeSuiteModel.Actions }
     *     
     */
    public BeforeSuiteModel.Actions getActions() {
        return actions;
    }

    /**
     * Legt den Wert der actions-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link BeforeSuiteModel.Actions }
     *     
     */
    public void setActions(BeforeSuiteModel.Actions value) {
        this.actions = value;
    }

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Ruft den Wert der suites-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSuites() {
        return suites;
    }

    /**
     * Legt den Wert der suites-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSuites(String value) {
        this.suites = value;
    }

    /**
     * Ruft den Wert der groups-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGroups() {
        return groups;
    }

    /**
     * Legt den Wert der groups-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGroups(String value) {
        this.groups = value;
    }


    /**
     * <p>Java-Klasse für anonymous complex type.</p>
     * 
     * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <sequence>
     *         <choice maxOccurs="unbounded">
     *           <any namespace='http://www.citrusframework.org/schema/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/jms/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/ws/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/http/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/camel/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/selenium/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/docker/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/kubernetes/testcase'/>
     *           <any namespace='http://www.citrusframework.org/schema/zookeeper/testcase'/>
     *         </choice>
     *       </sequence>
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "anies"
    })
    public static class Actions {

        @XmlAnyElement(lax = true)
        protected List<Object> anies;

        /**
         * Gets the value of the anies property.
         * 
         * <p>This accessor method returns a reference to the live list,
         * not a snapshot. Therefore any modification you make to the
         * returned list will be present inside the JAXB object.
         * This is why there is not a <CODE>set</CODE> method for the anies property.</p>
         * 
         * <p>
         * For example, to add a new item, do as follows:
         * </p>
         * <pre>
         * getAnies().add(newItem);
         * </pre>
         * 
         * 
         * <p>
         * Objects of the following type(s) are allowed in the list
         * {@link Object }
         * </p>
         * 
         * 
         * @return
         *     The value of the anies property.
         */
        public List<Object> getAnies() {
            if (anies == null) {
                anies = new ArrayList<>();
            }
            return this.anies;
        }

    }

}
